# Change History

## 2022.6.29

* Added -H, --human option to offer reporting the total "mass" purged as well as duration the execution took in easier to grok quantities and units
* Shield against spaces as paths and more clearly indicate when no valid path was assessed at all

## 2022.6.28

* Hotfix to make new duration reporting useful

## 2022.6.27

* Maintenance release with updated dependencies (production, development, and test)

## 2021
### 2021.12.16

* Fixed app not starting issue #54 (Fix the startup error for standalone app)

### 2021.10.24

* Intermediate release with new dev tools
* Changed name of package will deal with depreaction of the package under the old name [`purge_range`](https://pypi.org/project/purge-range/) later.
* Followed the name change of upstream [`prefix_compression`](https://pypi.org/project/prefix-compression/) package to [`puristaa`](https://pypi.org/project/puristaa/)
* No functional changes

### 0.0.2 (2021-05-13)

* Second release on PyPI as purge_range

### 0.0.1 (2021-05-08)

* Initial release on PyPI as purge_range

